"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
const puppeteer_1 = __importDefault(require("puppeteer"));
const utils_1 = require("./utils");
let browser, page;
module.exports = async function (data) {
    try {
        // 是否以 http 协议开头
        data.url = (0, utils_1.isHttp)(data.url) ? data.url : 'http://' + data.url;
        // 判断是服务器(Server)还是无服务器(ServerLess)，决定使用Chromium
        const launchOpt = await (0, utils_1.launch)(data.font);
        if (!browser)
            browser = await puppeteer_1.default.launch(launchOpt);
        // 创建新的标签页
        page = await browser.newPage();
        // 设置截图宽高比
        if (data.viewport) {
            const viewport = data.viewport.split('x');
            if (viewport.length === 1)
                viewport.push(viewport[0]);
            data.viewport = {
                width: parseInt(viewport[0]),
                height: parseInt(viewport[1]),
                isMobile: (0, utils_1.isBoolean)(data.isMobile)
            };
            await page.setViewport(data.viewport); // 设置页面大小
        }
        // 打开网站
        const gotoOpt = (0, utils_1.goto)(data); // 打开网站选项
        await page.goto(data.url, gotoOpt);
        // 页面渲染完成后等待(毫秒)
        await new Promise((r) => setTimeout(r, gotoOpt.await));
        // 截图
        const screenshotOpt = (0, utils_1.screenshot)(data); // 截图选项
        return await page.screenshot(screenshotOpt);
    }
    catch (error) {
        // eslint-disable-next-line
        console.error(error);
        if (browser) {
            browser.close();
            browser = null;
        }
    }
    finally {
        if (page) {
            await page.close();
            page = null;
        }
    }
    return '';
};
