"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.cache = exports.screenshot = exports.goto = exports.launch = exports.clip = exports.deepClone = exports.isHttp = exports.isNumber = exports.isBoolean = void 0;
/* eslint-disable @typescript-eslint/no-explicit-any */
const path_1 = require("path");
const chrome_aws_lambda_1 = __importDefault(require("chrome-aws-lambda"));
function isBoolean(value) {
    return value === 'true' || value === true ? true : false;
}
exports.isBoolean = isBoolean;
function isNumber(value) {
    return !isNaN(value);
}
exports.isNumber = isNumber;
function isHttp(url) {
    return /^https?:\/\//.test(url);
}
exports.isHttp = isHttp;
function deepClone(data) {
    try {
        return JSON.parse(JSON.stringify(data));
    }
    catch (error) {
        return {};
    }
}
exports.deepClone = deepClone;
function clip(data) {
    if (!data.clip)
        return;
    const clip = data.clip.split(',');
    const opt = {
        x: parseInt(clip[0]),
        y: parseInt(clip[1]),
        width: parseInt(clip[2]),
        height: parseInt(clip[3])
    };
    return opt;
}
exports.clip = clip;
async function launch(fontUrl) {
    // 设置字体: 文泉驿宽微米黑
    const fontPath = (0, path_1.join)(__dirname, '../font/WenQuanDengKuanWeiMiHei-1.ttf');
    // 判断是否是url字体
    const font = isHttp(fontUrl) ? fontUrl : fontPath;
    // 使用字体
    await chrome_aws_lambda_1.default.font(font);
    // local (Server) 配置
    const localOptions = {};
    if (process.env.PUPPETEER_EXECUTABLE_PATH) {
        localOptions.executablePath = process.env.PUPPETEER_EXECUTABLE_PATH;
    }
    // lambda (ServerLess) 配置
    const lambdaOptions = {
        args: chrome_aws_lambda_1.default.args,
        headless: chrome_aws_lambda_1.default.headless
    };
    if (!process.env.PUPPETEER_SERVER) {
        lambdaOptions.executablePath = await chrome_aws_lambda_1.default.executablePath;
    }
    // 判断是服务器(Server)还是无服务器(ServerLess)
    return process.env.PUPPETEER_SERVER ? localOptions : lambdaOptions;
}
exports.launch = launch;
function goto(data) {
    const options = {};
    // 超时，默认30s
    // if (isNumber(data.timeout)) {
    //   options.timeout = Math.abs(data.timeout) ?? 30000
    // }
    // 源码如上，为了适配低于v12.x的nodejs版本，改为如下写法
    if (isNumber(data.timeout)) {
        const timeout = Math.abs(data.timeout);
        // eslint-disable-next-line eqeqeq
        options.timeout = timeout == void 0 ? 30000 : timeout;
    }
    // 页面渲染完成后等待(毫秒)
    if (isNumber(data.await))
        options.await = Math.abs(data.await) || 0;
    // 什么模式下截图
    const waitUntils = [
        'load',
        'domcontentloaded',
        'networkidle0',
        'networkidle2' // 500ms 内只有2个请求时
    ];
    options.waitUntil = waitUntils.includes(data.waitUntil) ? data.waitUntil : waitUntils[0];
    return options;
}
exports.goto = goto;
function screenshot(data) {
    const options = {};
    // 图片质量 `1-100` 对 `png` 类型无效
    if (isNumber(data.quality))
        options.quality = Math.abs(data.quality);
    // 图片类型
    const types = ['png', 'jpeg', 'webp'];
    options.type = types.includes(data.type) ? data.type : types[0];
    // 图片编码
    const encodings = ['binary', 'base64'];
    options.encoding = encodings.includes(data.encoding) ? data.encoding : encodings[0];
    // 截取完整页面
    options.fullPage = isBoolean(data.fullPage);
    // 截取指定坐标以及宽高
    const clipOpt = clip(data);
    if (clipOpt)
        options.clip = clipOpt;
    return options;
}
exports.screenshot = screenshot;
function cache(cache) {
    // 不适用 http 强制缓存
    if (cache === 'false')
        return;
    const sec = Math.abs(cache);
    const daySec = 86400;
    const cacheKey = 'public, no-transform, s-maxage=$, max-age=$';
    // eslint-disable-next-line eqeqeq
    if (cache == void 0)
        return cacheKey.replace(/\$/g, daySec);
    if (isNumber(sec))
        return cacheKey.replace(/\$/g, sec);
}
exports.cache = cache;
